@@ -365,7 +365,9 @@ init.plot <- ggplot(data=plot.data, aes_(x=~time, y=~logUguess))+
   ggtitle(title, subtitle="Initial spline fit to estimated log U[i]")+
   geom_point()+
   geom_line(aes_(y=~spline))+
-  xlab("Stratum")+ylab("log(U[i])")
+  xlab("Stratum")+ylab("log(U[i])")+
+  scale_x_continuous(breaks=seq(min(plot.data$time, na.rm=TRUE),max(plot.data$time, na.rm=TRUE),2))
+
 if(save.output.to.files)ggsave(init.plot, filename=paste(prefix,"-initialU.pdf",sep=""), height=4, width=6, units="in")
 #results$plots$plot.init <- init.plot  # do this after running the MCMC chain (see end of function)
 
